2021-01-27 Version: 1.0.0
- Generated python 2017-12-14 for BssOpenApi.

2021-01-19 Version: 0.1.2
- Generated python 2017-12-14 for BssOpenApi.

2020-09-24 Version: 0.1.1
- Supported query account transactions.

